html, body {
    width: 100%;
    padding: 0;
    margin: 0;
    box-sizing: border-box;
}

body {
    padding: 10px;
    font-family: sans-serif;
    line-height: 1.6;
    text-wrap-style: pretty;
    background: #fff;
}

.container {
    max-width: 900px;
    margin: auto;
    padding: 10px 20px;
    box-sizing: border-box;
    width: 100%;
}

.score {
    background: #2ecc71;
    color: white;
    padding: 10px;
    border-radius: 5px;
    text-align: center;
}

.section {
    margin: 20px 0;
    padding: 10px 20px;
    border-radius: 6px;
    border: 1px solid #ddd;
}

.section-ok {
    background: #eafaf1;
}

.section-warn {
    background: #fff9e6;
}

.section-error {
    background: #faeaea;
}

h2 {
    border-bottom: 1px solid #ccc;
}

h3 {
    margin-top: 1em;
}

a {
    color: #2980b9;
    text-decoration: none;
}

li {
    margin: 4px 0;
    word-break: keep-all;
    white-space: normal;
}

code {
    background: #eee;
    padding: 1px 4px;
    border-radius: 4px;
}

@media (max-width: 600px) {
    .container {
        padding: 10px;
    }

    .section {
        padding: 10px;
    }

    .score {
        font-size: 1em;
    }

    h2, h3 {
        font-size: 1em;
    }
}